@@ -71,9 +71,21 @@ public class AzureDevOpsPersonalAccessTokenFetcher implements PersonalAccessToke
     this.azureDevOpsApiClient = azureDevOpsApiClient;
   }
 
+  @Override
+  public PersonalAccessToken refreshPersonalAccessToken(Subject cheSubject, String scmServerUrl)
+      throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
+    return fetchOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, true);
+  }
+
   @Override
   public PersonalAccessToken fetchPersonalAccessToken(Subject cheSubject, String scmServerUrl)
       throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
+    return fetchOrRefreshPersonalAccessToken(cheSubject, scmServerUrl, false);
+  }
+
+  private PersonalAccessToken fetchOrRefreshPersonalAccessToken(
+      Subject cheSubject, String scmServerUrl, boolean forceRefreshToken)
+      throws ScmUnauthorizedException, ScmCommunicationException, UnknownScmProviderException {
     OAuthToken oAuthToken;
 
     if (!isValidScmServerUrl(scmServerUrl)) {
@@ -82,7 +94,10 @@ public class AzureDevOpsPersonalAccessTokenFetcher implements PersonalAccessToke
     }
 
     try {
-      oAuthToken = oAuthAPI.getToken(AzureDevOps.PROVIDER_NAME);
+      oAuthToken =
+          forceRefreshToken
+              ? oAuthAPI.refreshToken(AzureDevOps.PROVIDER_NAME)
+              : oAuthAPI.getOrRefreshToken(AzureDevOps.PROVIDER_NAME);
       String tokenName = NameGenerator.generate(OAUTH_2_PREFIX, 5);
       String tokenId = NameGenerator.generate("id-", 5);
       Optional<Pair<Boolean, String>> valid =
