@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Red Hat, Inc.
+ * Copyright (c) 2012-2024 Red Hat, Inc.
  * This program and the accompanying materials are made
  * available under the terms of the Eclipse Public License 2.0
  * which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -82,7 +82,8 @@ public class BitbucketAuthorizingFileContentProviderTest {
     // given
     URLFetcher urlFetcher = Mockito.mock(URLFetcher.class);
     String url = "https://bitbucket.org/workspace/repository/raw/HEAD/devfile.yaml";
-    PersonalAccessToken personalAccessToken = new PersonalAccessToken(url, "che", "my-token");
+    PersonalAccessToken personalAccessToken =
+        new PersonalAccessToken(url, "provider", "che", "my-token");
     when(personalAccessTokenManager.getAndStore(anyString())).thenReturn(personalAccessToken);
     when(bitbucketApiClient.getFileContent(
             eq("workspace"), eq("repository"), eq("HEAD"), eq("devfile.yaml"), eq("my-token")))
